@@ -11,14 +11,15 @@
 
 struct genitem {
 	short	ef_type;
-        coord	x, y;
         natid	own;
+        short	uid;
+        coord	x;
+	coord	y;
         s_char	type;
         s_char	effic;
         s_char	mobil;
         short	sell;
         short	tech;
-        short	uid;
         s_char	group;
 	coord	opx,opy;
 	short	mission;
