@@ -28,6 +28,7 @@ static char *RCSid = "$Header: /usr/brule/guest/empire/empire/emprcs/lib/subs/sh
 #include "mission.h"
 #include "optlist.h"
 #include "damage.h"
+#include "edb.h"
 
 void
 shp_sel(ni, list/*, wantflags, nowantflags */)
@@ -527,6 +528,7 @@ notify_coastguard(list, trange, sectp)
 		mlp = (struct mlist *) qp;
 		if (mlp->mcp->m_flags & M_SUB)
 			continue;
+		prsync(sectp->sct_own, &mlp->ship, EDV_COAS);
 		wu(0, sectp->sct_own,
 		   "%s %s sighted at %s\n",
 		   cname(mlp->ship.shp_own),
